Learn R Programming

BMAmevt (version 1.0.5)

BMAmevt-package: Bayesian Model Averaging for Multivariate Extremes

Description

Toolkit for Bayesian estimation of the dependence structure in Multivariate Extreme Value parametric models, with possible use of Bayesian model Averaging techniques Includes a Generic MCMC sampler. Estimation of the marginal distributions is a prerequisite, e.g. using one of the packages ismev, evd, evdbayes or POT. This package handles data sets which are assumed to be marginally unit-Frechet distributed.

Arguments

Author

Anne Sabourin

See Also

evdbayes