Learn R Programming

BMAmevt (version 1.0.5)

ddirimix: Angular density/likelihood function in the Dirichlet Mixture model.

Description

Likelihood function (spectral density on the simplex) and angular data sampler in the Dirichlet mixture model.

Usage

ddirimix(
  x = c(0.1, 0.2, 0.7),
  par,
  wei = par$wei,
  Mu = par$Mu,
  lnu = par$lnu,
  log = FALSE,
  vectorial = FALSE
)

rdirimix( n = 10, par = get("dm.expar.D3k3"), wei = par$wei, Mu = par$Mu, lnu = par$lnu )

Value

ddirimix returns the likelihood as a single number if vectorial ==FALSE, or as a vector of size nrow(x) containing the likelihood of each angular data point. If log == TRUE, the log-likelihood is returned instead. rdirimix returns a matrix with n points and p=nrow(Mu) columns.

Arguments

x

An angular data set which may be reduced to a single point: A \(n*p\) matrix or a vector of length p, where \(p\) is the dimension of the sample space and \(n\) is the sample size. Each row is a point on the simplex, so that each row sum to one. The error tolerance is set to 1e-8 in this package.

par

The parameter list for the Dirichlet mixture model.

wei

Optional. If present, overrides the value of par$wei.

Mu

Optional. If present, overrides the value of par$Mu.

lnu

Optional. If present, overrides the value of par$lnu.

log

Logical: should the density or the likelihood be returned on the log-scale ?

vectorial

Logical: Should a vector of size \(n\) or a single value be returned ?

n

The number of angular points to be generated

Details

The spectral probability measure defined on the simplex characterizes the dependence structure of multivariate extreme value models. The parameter list for a mixture with \(k\) components, is made of

Mu

The density kernel centers \(\mu_{i,m}, 1\le i \le p, 1\le m \le k\) : A \(p*k\) matrix, which columns sum to one, and such that Mu %*% wei=1, for the moments constraint to be satisfied. Each column is a Dirichlet kernel center.

wei

The weights vector for the kernel densities: A vector of \(k\) positive numbers summing to one.

lnu

The logarithms of the shape parameters \(nu_m, 1\le m \le k\) for the density kernels: a vector of size \(k\).

The moments constraint imposes that the barycenter of the columns in Mu, with weights wei, be the center of the simplex.