Only valid in the tri-variate case
ddirimix.grid(
par = get("dm.expar.D3k3"),
wei = par$wei,
Mu = par$Mu,
lnu = par$lnu,
npoints = 30,
eps = 10^(-3),
equi = TRUE,
marginal = TRUE,
coord = c(1, 2, 3),
invisible = TRUE,
displ = TRUE,
...
)The discretized density
The parameter list for the Dirichlet mixture model.
Optional. If present, overrides the value of
par$wei.
Optional. If present, overrides the value of
par$Mu.
Optional. If present, overrides the value of
par$lnu.
The number of grid nodes on the squared grid containing the desired triangle.
Positive number: minimum distance from any node inside the simplex to the simplex boundary
logical. Is the simplex represented as an equilateral triangle (if TRUE) or a right triangle (if FALSE) ?
logical. If TRUE, the angular density corresponds to the marginal intensity measure, over coordinates coord. Otherwise, it is only the projection of the full dimensional angular measure (hence the moments constraints is not satisfied anymore).
A vector of size 3: the indices of the coordinates upon which the marginalization is to be done.
Logical: should the result be returned as invisible ?
Logical: should a plot be issued ?
Additional arguments to be passed to
dgridplot.