[0,1]Plots a univariate Dirichlet mixture (in other words, a Beta mixture) angular density for extreme bi-variate data.
ddirimix.grid1D(
par = get("dm.expar.D2k4"),
wei = par$wei,
Mu = par$Mu,
lnu = par$lnu,
npoints = 30,
eps = 10^(-3),
coord = c(1, 2),
marginal = TRUE,
invisible = TRUE,
displ = TRUE,
add = FALSE,
...
)The discretized density on [eps, 1-eps] (included in [0,1])
The parameter list for the Dirichlet mixture model.
Optional. If present, overrides the value of
par$wei.
Optional. If present, overrides the value of
par$Mu.
Optional. If present, overrides the value of
par$lnu.
number of points on the 1D discretization grid.
the minimum value ( = 1- the maximum value) of the grid points.
A vector of size 2: the indices of the coordinates upon which the marginalization or projection is to be done if the dimension of the sample space is greater than two.
logical. If TRUE, the angular density corresponds to the marginal intensity measure of the extreme Poisson process, over coordinates coord. Otherwise, it is only the projection of the full dimensional angular measure (hence the moments constraints is not satisfied anymore).
Logical: should the result be returned as invisible ?
Logical: should a plot be issued ?
Logical: should the density be added to the currently active plot ?
Additional arguments to be passed to plot