Learn R Programming

BMAmevt (version 1.0.5)

discretize: Discretization grid builder.

Description

Builds a discretization grid covering the two-dimensional unit simplex, with specified number of points and minimal distance from the boundary.

Usage

discretize(npoints = 40, eps = 0.001, equi = FALSE)

Value

A list containing two elements: X and Y, vectors of size npoints, the Cartesian coordinates of the grid nodes.

Arguments

npoints

The number of grid nodes on the squared grid containing the desired triangle.

eps

Positive number: minimum distance from any node inside the simplex to the simplex boundary

equi

logical. Is the simplex represented as an equilateral triangle (if TRUE) or a right triangle (if FALSE) ?

Details

The npoints*npoints grid covers either the equilateral representation of the simplex, or the right angled one. In any case, the grid is rectangular: some nodes lie outside the triangle. Density computations on such a grid should handle the case when the point passed as argument is outside the simplex (typically, the function should return zero in such a case).