The Dirichlet mixture density has three components, the center of mass of the three columns of Mu, with weights wei is \((1/3,1/3,1/3)\): the centroid of the two dimensional unit simplex.
A list made of
A \(3*3\) matrix, which rows sum to one, such that the
center of mass of the three column vectors (weighted with wei) is the centroid of the simplex: each column is the center of a Dirichlet mixture component.
A vector of length three, summing to one: the mixture weights
A vector of length three: the logarithm of the concentration parameters.