Posterior distribution the probability of joint threshold excess, in the NL model.
excessProb.nl(
post.sample,
from = NULL,
to = NULL,
thin = 100,
thres = rep(100, 3),
known.par = FALSE,
true.par,
displ = FALSE
)A list made of
The output of posteriorMean called with FUN=excessProb.condit.nl.
The posterior mean of the excess probability
The standard deviation of the mean estimator
The standard deviation of the excess probability, in the posterior sample.
The lower 0.1 quantile of the empirical posterior distribution of the excess probability
The upper 0.1 quantile of the empirical posterior distribution of the excess probability
NULL if known.par=FALSE, otherwise the excess probability in the true model.
The posterior sample, as returned by posteriorMCMC
Integer or NULL. If NULL, the default value is used. Otherwise, should be greater than post.sample$Nbin. Indicates the index where the averaging process should start. Default to post.sample$Nbin +1
Integer or NULL. If NULL, the default
value is used. Otherwise, must be lower than Nsim+1.
Indicates where the averaging process should stop.
Default to post.sample$Nsim.
Thinning interval.
a positive vector of size three.
logical. Is the true parameter known ?
The true parameter, only used if known.par=TRUE
logical. Should a plot be produced ?