Approximation of a model marginal likelihood by Laplace method.
laplace.evt(
mode = NULL,
npar = 4,
likelihood,
prior,
Hpar,
data,
link,
unlink,
method = "L-BFGS-B"
)A list made of
the parameter (on the unlinked scale) deemed to maximize the posterior density. This is equal to the argument if the latter is not null.
The value of the posterior, evaluated at mode.
The logarithm of the estimated marginal likelihood
The inverse of the estimated hessian matrix at mode
The parameter vector (on the “unlinked” scale, i.e. before transformation to the real line)
which maximizes the posterior density, or NULL.
The size of the parameter vector. Default to four.
The likelihood function, e.g. dpairbeta or dnestlog
The prior density (takes an “unlinked” parameter as argument and returns the density of the linked parameter)
The prior hyper parameter list.
The angular dataset
The link function, from the “classical” or “unlinked” parametrization onto the real line. (e.g. log for the PB model, an logit for the NL model)
The inverse link function (e.g. exp for the PB model and invlogit for the NL model)
The optimization method to be used. Default to "L-BFGS-B".
The posterior mode is either supplied, or approximated by numerical optimization. For an introduction about Laplace's method, see e.g. Kass and Raftery, 1995 and the references therein.
KASS, R.E. and RAFTERY, A.E. (1995). Bayes Factors. Journal of the American Statistical Association, Vol. 90, No.430