Learn R Programming

BMAmevt (version 1.0.5)

nl.MCpar: Default MCMC tuning parameter for the Nested Asymmetric logistic model.

Description

The proposals (on the logit-scale) are Gaussian, centered aroud the current value.

Arguments

Format

A list made of a single element: sd. The standard deviation of the normal proposition kernel centered at the (logit-transformed) current state. Default to \(0.35\).