Learn R Programming

BMAmevt (version 1.0.5)

pb.MCpar: Default MCMC tuning parameter for the Pairwise Beta model.

Description

The proposal for the log-transformed parameters are Gaussian, centered at the current value.

Arguments

Format

A list made of a single element: sd, the standard deviation of the normal proposition kernel (on the log-transformed parameter). Default to \(0.35\).