Wrappers for posterior.predictive3D in the PB and NL models.
posterior.predictive.nl(
post.sample,
from = post.sample$Nbin + 1,
to = post.sample$Nsim,
thin = 50,
npoints = 40,
eps = 0.001,
equi = T,
displ = T,
...
)posterior.predictive.pb(
post.sample,
from = post.sample$Nbin + 1,
to = post.sample$Nsim,
thin = 50,
npoints = 40,
eps = 10^(-3),
equi = T,
displ = T,
...
)
A npoints*npoints matrix: the posterior predictive density.
A posterior sample as returned by posteriorMCMC
Integer or NULL. If NULL, the default value is used. Otherwise, should be greater than post.sample$Nbin. Indicates the index where the averaging process should start. Default to post.sample$Nbin +1
Integer or NULL. If NULL, the default
value is used. Otherwise, must be lower than Nsim+1.
Indicates where the averaging process should stop.
Default to post.sample$Nsim.
Thinning interval.
The number of grid nodes on the squared grid containing the desired triangle.
Positive number: minimum distance from any node inside the simplex to the simplex boundary
logical. Is the simplex represented as an equilateral triangle (if TRUE) or a right triangle (if FALSE) ?
logical. Should a plot be produced ?
Additional graphical parameters and arguments to be passed
to contour and image.
The posterior predictive density is approximated by averaging the densities corresponding to the parameters stored in post.sample. See
posterior.predictive3D for details.
posterior.predictive3D, posteriorMCMC.pb.