The data set is constructed from coordinates (columns) \(1,2,3\) of frechetdat.
It contains 100 angular points corresponding to the tri-variate vectors \(V=(X,Y,Z)\) with largest \(L^1\) norm (\(||V||=X+Y+Z\)). The angular points are obtained by ‘normalizing’: e.g.,
\(x=X/||V||\). Thus,
each row in Leeds is a point on the two-dimensional simplex : \(x+y+z=1\).
A \(100*3\) - matrix.
COOLEY, D., DAVIS, R. and NAVEAU, P. (2010). The pairwise beta distribution: A flexible parametric multivariate model for extremes. Journal of Multivariate Analysis 101, 2103-2117
RESNICK, S. (1987). Extreme values, regular variation, and point processes, Applied Probability. A, vol. 4, Series of the Applied Probability Trust. Springer-Verlag, New York.