Builds a discretization grid covering the two-dimensional unit simplex, with specified number of points and minimal distance from the boundary.
discretize(npoints = 40, eps = 0.001, equi = FALSE)A list containing two elements: X and Y, vectors of size npoints, the Cartesian coordinates of the grid nodes.
The number of grid nodes on the squared grid containing the desired triangle.
Positive number: minimum distance from any node inside the simplex to the simplex boundary
logical. Is the simplex represented as an equilateral triangle (if TRUE) or a right triangle (if FALSE) ?
The npoints*npoints grid covers either
the equilateral representation of
the simplex, or the right angled one.
In any case, the grid is
rectangular: some nodes lie outside the triangle.
Density computations on such a grid should handle the case when
the point passed as argument is outside the simplex (typically,
the function should return zero in such a case).