Switching coordinates system between equilateral and right-angled
representation of the two-dimensional simplex.
Usage
transf.to.equi(vect)
transf.to.rect(vect)
Value
The vector obtained by linear transformation.
Arguments
vect
a bi-variate vector, giving the first two coordinates of the angular point to be transformed.
Author
Anne Sabourin
Details
If transf.to.rect, is called, vect must belongs to the triangle \([(0,0), (\sqrt(2), 0), (\sqrt(2)/2,\sqrt(3/2) ) ]\)
and the result lies in \(([(0,0), (1,0), (0,1)]\). transf.to.equi is the reciprocal.